Crate ap_proxy_protocol

Crate ap_proxy_protocol 

Shared wire protocol types for the ap-proxy WebSocket server.

This crate contains the protocol types used by both the proxy server and proxy client, with zero TLS dependencies.

Re-exports

pub use auth::Challenge;
pub use auth::ChallengeResponse;
pub use auth::Identity;
pub use auth::IdentityFingerprint;
pub use auth::IdentityKeyPair;
pub use auth::SignatureAlgorithm;
pub use error::ProxyError;
pub use messages::Messages;
pub use rendezvous::RendezvousCode;

Modules

auth
Authentication module for the ap-proxy crate. Authentication works by creating a cryptographic identity - a signature key-pair. The identity is the public key. It is proven to the proxy, by signing a challenge provided by the proxy using the signature key.
error
Error types for proxy operations.
messages
Protocol message types for client-proxy communication.
rendezvous
Rendezvous codes for temporary peer discovery.